/**
 * Classe oggetto che rappresenta un ordine.
 * 
 * @author Damiano Macedonio
 * @version 1.0
 */

public class Ordine {
	/**
	 * Massimo numero di pizze consentite per ordine.
	 */
	private static final int MAX_PIZZE = 10;
	
	/**
	 * Vettore contenente le pizze che costituiscono l'ordine.
	 */
	private Pizza[] pizze = new Pizza[MAX_PIZZE];
	
	/**
	 * Somma dei prezzi delle pizze in ordine.
	 */
	private double totale;
	
	/**
	 * Ritorna il prezzo totale dell'ordine. 
	 *
	 * @return  prezzo totale dell'ordine
	 */
	public double getTotale() {
		return totale;
	}

	/**
	 * Aggiunge una pizza all'ordine. 
	 * La pizza non viene aggiunta se il numero di pizze in ordine e' pari a <code>MAX_PIZZE</code>.
	 * 
	 * @param p pizza da aggiungere all'ordine
	 * @return <code>true</code> se l'inserimento ha avuto successo, <code>false</code> altrimenti
	 */
	public boolean aggiungiPizza(Pizza p){
		int i = 0;
		while (i < MAX_PIZZE && pizze[i] != null)
			i++;
		if (i < MAX_PIZZE) {
			pizze[i] = p;
			totale += p.getPrezzo();
			return true;
		}
		return false;
	}
	
	/**
	 * Ritorna una descrizione testuale dell'ordine. 
	 *
	 * @return  descrizione testuale dell'ordine
	 */
	public String toString(){
		String str ="";
		for(Pizza p : pizze)
			if (p != null)
				str += p.getNome() + "\t" + p.getPrezzo() + "\n";
		str += "\t\t Totale: " + this.totale;
		return str;
	}

}
