/**
 * Classe oggetto che rappresenta una pizza.
 * 
 * @author Damiano Macedonio
 * @version 1.0
 */

public class Pizza {
	
	/**
	 * Nome della pizza.
	 */
	private String nome;
	
	/**
	 * Vettore degli ingredienti che costituiscono la pizza.
	 */
	private Ingrediente[] ingredienti = new Ingrediente[0];

	/**
	 * Crea un nuovo oggetto Pizza con parametri impostati dall'utente.
	 * 
	 * @param nome nome della pizza
	 */
	public Pizza(String nome) {
		this.nome = nome;
	}
	
		
	/**
	 * Ritorna il nome della pizza. 
	 *
	 * @return  nome della pizza
	 */
	public String getNome() {
		return nome;
	}
	
	/**
	 * Aggiunge un ingrediente alla pizza. 
	 *
	 * @param ing  ingredienate da aggiungere
	 */
	public void aggiungiIngrediente(Ingrediente ing) {
		Ingrediente[] estensione = new Ingrediente[ingredienti.length + 1];
		for (int k = 0; k < ingredienti.length; k++)
			estensione[k] = ingredienti[k];
		estensione[estensione.length - 1] = ing;
		ingredienti = estensione;
	}


	/**
	 * Ritorna il prezzo della pizza. 
	 *
	 * @return  prezzo della pizza
	 */
	public double getPrezzo() {
		double prezzo = .0;
		for(Ingrediente i : this.ingredienti)
			prezzo += i.getPrezzo();
		return prezzo;
	}

	
	/**
	 * Ritorna una descrizione testuale della pizza. 
	 *
	 * @return  descrizione testuale della pizza
	 */
	public String toString(){
		String str = "";
		str = "Pizza: " + this.nome + "\n";
		for (Ingrediente i : ingredienti)
			str += "\t\t" + i.getNome() + "\n";
		str += "Prezzo: " + this.getPrezzo();
		return str;
		
	}
	
}
